@@ -47,6 +47,8 @@ atoms = [
     ([
         (abs, (2, 2), [ [[-5,2],[-3,1]] ],
             Constant([[5,2],[3,1]])),
+        (diag, (2, 1), [ [[-5,2],[-3,1]] ], Constant([-5, 1])),
+        (diag, (2, 2), [ [-5, 1] ], Constant([[-5, 0], [0, 1]])),
         (exp, (2, 2), [ [[1, 0],[2, -1]] ],
             Constant([[math.e, 1],[math.e**2, 1.0/math.e]])),
         (huber, (2, 2), [ [[0.5, -1.5],[4, 0]] ],
@@ -142,7 +144,7 @@ def check_solver(prob, solver):
     try:
         prob._validate_solver(constr_map, solver)
         return True
-    except Exception, e:
+    except Exception as e:
         return False
 
 # Tests numeric version of atoms.
